@@ -4,24 +4,26 @@ use clap::{Parser, Subcommand};
 
 pub mod export;
 pub mod import;
+pub mod lint;
+pub mod list;
 
 #[derive(Parser, Debug)]
 #[clap(
     name = "cert",
-    about = "Manages certificates",
+    about = "Manage certificates",
     long_about =
-"Manages certificates
+"Manage certificates
 
-We use the term \"certificate\", or \"cert\" for short, to refer to
-OpenPGP keys that do not contain secrets.  This subcommand provides
+We use the term \"certificate\", or \"cert\" for short, to refer to \
+OpenPGP keys that do not contain secrets.  This subcommand provides \
 primitives to generate and otherwise manipulate certs.
 
-Conversely, we use the term \"key\" to refer to OpenPGP keys that do
+Conversely, we use the term \"key\" to refer to OpenPGP keys that do \
 contain secrets.  See `sq key` for operations on keys.
-
 ",
     subcommand_required = true,
     arg_required_else_help = true,
+    disable_help_subcommand = true,
 )]
 pub struct Command {
     #[clap(subcommand)]
@@ -32,4 +34,6 @@ pub struct Command {
 pub enum Subcommands {
     Import(import::Command),
     Export(export::Command),
+    List(list::Command),
+    Lint(lint::Command),
 }
