@@ -5,16 +5,14 @@ use clap::Parser;
 use crate::cli::examples;
 use examples::Action;
 use examples::Actions;
-use examples::Example;
 
 const EXAMPLES: Actions = Actions {
     actions: &[
-        Action::Example(Example {
-            comment: "Import a certificate.",
-            command: &[
-                "sq", "cert", "import", "juliet.pgp",
-            ],
-        }),
+        Action::example().comment(
+            "Import a certificate."
+        ).command(&[
+            "sq", "cert", "import", "juliet.pgp",
+        ]).build(),
     ]
 };
 
@@ -24,9 +22,6 @@ test_examples!(sq_cert_import, EXAMPLES);
 #[clap(
     name = "import",
     about = "Import certificates into the local certificate store",
-    long_about =
-"Import certificates into the local certificate store
-",
     after_help = EXAMPLES,
 )]
 pub struct Command {
