@@ -1,6 +1,8 @@
 use anyhow::Context as _;
+use std::cell::RefCell;
 use std::collections::HashMap;
 use std::io;
+use std::sync::Arc;
 
 use sequoia_openpgp as openpgp;
 use openpgp::types::SymmetricAlgorithm;
@@ -28,27 +30,28 @@ use sequoia_keystore as keystore;
 use crate::{
     cli,
     commands::{
-        VHelper,
+        verify::VHelper,
     },
     common::password,
+    common::ui,
     Sq,
-    load_certs,
     load_keys,
+    sq::TrustThreshold,
 };
 
 pub fn dispatch(sq: Sq, command: cli::decrypt::Command) -> Result<()> {
     tracer!(TRACE, "decrypt::dispatch");
 
-    let mut input = command.input.open()?;
-    let mut output = command.output.create_safe(sq.force)?;
+    let mut input = command.input.open("an encrypted message")?;
+    let mut output = command.output.create_safe(&sq)?;
+
+    let signers =
+        sq.resolve_certs_or_fail(&command.signers, TrustThreshold::Full)?;
 
-    let certs = load_certs(
-        command.sender_cert_file.iter().map(|s| s.as_ref()),
-    )?;
     // Fancy default for --signatures.  If you change this,
     // also change the description in the CLI definition.
     let signatures = command.signatures.unwrap_or_else(|| {
-        if certs.is_empty() {
+        if signers.is_empty() {
             // No certs are given for verification, use 0 as
             // threshold so we handle only-encrypted messages
             // gracefully.
@@ -60,14 +63,27 @@ pub fn dispatch(sq: Sq, command: cli::decrypt::Command) -> Result<()> {
         }
     });
     let secrets =
-        load_keys(command.secret_key_file.iter().map(|s| s.as_ref()))?;
+        load_keys(command.secret_key_file.iter())?;
     let session_keys = command.session_key;
-    decrypt(sq, &mut input, &mut output,
-            signatures, certs, secrets,
-            command.dump_session_key,
-            session_keys)?;
+    let result = decrypt(sq, &mut input, &mut output,
+                         signatures, signers, secrets,
+                         command.dump_session_key,
+                         session_keys);
+    if result.is_err() {
+        if let Some(path) = command.output.path() {
+            // Drop output here so that the file is persisted and
+            // can be deleted.
+            drop(output);
 
-    Ok(())
+            if let Err(err) = std::fs::remove_file(path) {
+                weprintln!("Decryption failed, failed to remove \
+                            output saved to {}: {}",
+                           path.display(), err);
+            }
+        }
+    }
+
+    result
 }
 
 pub struct Helper<'c, 'store, 'rstore>
@@ -75,9 +91,14 @@ pub struct Helper<'c, 'store, 'rstore>
 {
     vhelper: VHelper<'c, 'store, 'rstore>,
     secret_keys: HashMap<KeyID, (Cert, Key<key::SecretParts, key::UnspecifiedRole>)>,
-    key_identities: HashMap<KeyID, Fingerprint>,
+    key_identities: HashMap<KeyID, Arc<Cert>>,
     session_keys: Vec<cli::types::SessionKey>,
     dump_session_key: bool,
+
+    /// The fingerprint of the public key that we used to the decrypt
+    /// the message.  If None and decryption was success then we
+    /// decrypted it in some other.
+    decryptor: RefCell<Option<Fingerprint>>,
 }
 
 impl<'c, 'store, 'rstore> std::ops::Deref for Helper<'c, 'store, 'rstore>
@@ -107,8 +128,9 @@ impl<'c, 'store, 'rstore> Helper<'c, 'store, 'rstore>
     {
         let mut keys: HashMap<KeyID, (Cert, Key<key::SecretParts, key::UnspecifiedRole>)>
             = HashMap::new();
-        let mut identities: HashMap<KeyID, Fingerprint> = HashMap::new();
+        let mut identities: HashMap<KeyID, Arc<Cert>> = HashMap::new();
         for tsk in secrets {
+            let cert = Arc::new(tsk.clone().strip_secret_key_material());
             for ka in tsk.keys().secret()
                 // XXX: Should use the message's creation time that we do not know.
                 .with_policy(sq.policy, None)
@@ -117,7 +139,7 @@ impl<'c, 'store, 'rstore> Helper<'c, 'store, 'rstore>
                 let id: KeyID = ka.key().fingerprint().into();
                 let key = ka.key();
                 keys.insert(id.clone(), (tsk.clone(), key.clone()));
-                identities.insert(id.clone(), tsk.fingerprint());
+                identities.insert(id.clone(), cert.clone());
             }
         }
 
@@ -127,22 +149,33 @@ impl<'c, 'store, 'rstore> Helper<'c, 'store, 'rstore>
             key_identities: identities,
             session_keys,
             dump_session_key,
+            decryptor: RefCell::new(None),
         }
     }
 
     /// Checks if a session key can decrypt the packet parser using
     /// `decrypt`.
-    fn try_session_key<D>(&self, keyid: &KeyID,
-                          algo: SymmetricAlgorithm, sk: SessionKey,
-                          decrypt: &mut D)
-        -> Option<Option<Fingerprint>>
-        where D: FnMut(SymmetricAlgorithm, &SessionKey) -> bool
+    fn try_session_key(&self, fpr: &Fingerprint,
+                       algo: Option<SymmetricAlgorithm>, sk: SessionKey,
+                       decrypt: &mut dyn FnMut(Option<SymmetricAlgorithm>, &SessionKey) -> bool)
+                       -> Option<Option<Cert>>
     {
         if decrypt(algo, &sk) {
             if self.dump_session_key {
-                wprintln!("Session key: {}", hex::encode(&sk));
+                weprintln!("Session key: {}", hex::encode(&sk));
             }
-            Some(self.key_identities.get(keyid).cloned())
+
+            // XXX: make key identities map to certs, and failing that
+            // look into the cert store.
+            let cert = self.key_identities.get(&KeyID::from(fpr)).cloned();
+            if let Some(cert) = &cert {
+                // Prefer the reverse-mapped identity.
+                self.decryptor.replace(Some(cert.fingerprint()));
+            } else {
+                // But fall back to the public key's fingerprint.
+                self.decryptor.replace(Some(fpr.clone()));
+            }
+            Some(cert.map(|c| (*c).clone()))
         } else {
             None
         }
@@ -150,16 +183,33 @@ impl<'c, 'store, 'rstore> Helper<'c, 'store, 'rstore>
 
     /// Tries to decrypt the given PKESK packet with `keypair` and try
     /// to decrypt the packet parser using `decrypt`.
-    fn try_decrypt<D>(&self, pkesk: &PKESK,
-                      sym_algo: Option<SymmetricAlgorithm>,
-                      mut keypair: Box<dyn crypto::Decryptor>,
-                      decrypt: &mut D)
-                      -> Option<Option<Fingerprint>>
-        where D: FnMut(SymmetricAlgorithm, &SessionKey) -> bool
+    fn try_decrypt(&self, pkesk: &PKESK,
+                   sym_algo: Option<SymmetricAlgorithm>,
+                   mut keypair: Box<dyn crypto::Decryptor>,
+                   decrypt: &mut dyn FnMut(Option<SymmetricAlgorithm>, &SessionKey) -> bool)
+                   -> Option<Option<Cert>>
     {
-        let keyid = keypair.public().fingerprint().into();
+        let fpr = keypair.public().fingerprint();
         let (sym_algo, sk) = pkesk.decrypt(&mut *keypair, sym_algo)?;
-        self.try_session_key(&keyid, sym_algo, sk, decrypt)
+        self.try_session_key(&fpr, sym_algo, sk, decrypt)
+    }
+
+    /// Prints what certificate was used to decrypt the message.
+    fn print_status(&self) {
+        make_qprintln!(self.quiet);
+
+        let decryptor = self.decryptor.borrow();
+        if let Some(ref fpr) = *decryptor {
+            let kh = KeyHandle::from(fpr);
+
+            if let Ok(cert) = self.sq.lookup_one(kh, None, true) {
+                qprintln!("Decrypted by {}, {}",
+                          cert.fingerprint(),
+                          self.sq.best_userid(&cert, true).display());
+            } else {
+                qprintln!("Decrypted by {}, unknown", fpr);
+            }
+        }
     }
 }
 
@@ -177,23 +227,23 @@ impl<'c, 'store, 'rstore> VerificationHelper for Helper<'c, 'store, 'rstore>
 impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
     where 'store: 'rstore
 {
-    fn decrypt<D>(&mut self, pkesks: &[PKESK], skesks: &[SKESK],
-                  sym_algo: Option<SymmetricAlgorithm>,
-                  mut decrypt: D) -> openpgp::Result<Option<Fingerprint>>
-        where D: FnMut(SymmetricAlgorithm, &SessionKey) -> bool
+    fn decrypt(&mut self, pkesks: &[PKESK], skesks: &[SKESK],
+               sym_algo: Option<SymmetricAlgorithm>,
+               decrypt: &mut dyn FnMut(Option<SymmetricAlgorithm>, &SessionKey) -> bool)
+               -> openpgp::Result<Option<Cert>>
     {
         make_qprintln!(self.quiet);
 
         // Before anything else, try the session keys
         for sk in &self.session_keys {
             let decrypted = if let Some(sa) = sk.symmetric_algo {
-                decrypt(sa, &sk.session_key)
+                decrypt(Some(sa), &sk.session_key)
             } else {
                 // We don't know which algorithm to use,
                 // try to find one that decrypts the message.
                 (1u8..=19)
                     .map(SymmetricAlgorithm::from)
-                    .any(|sa| decrypt(sa, &sk.session_key))
+                    .any(|sa| decrypt(Some(sa), &sk.session_key))
             };
             if decrypted {
                 qprintln!("Encrypted with Session Key {}",
@@ -212,15 +262,16 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                     let keypair = Box::new(key.into_keypair()
                         .expect("decrypted secret key material"));
 
-                    slf.try_decrypt(pkesk, sym_algo, keypair, &mut decrypt)
+                    slf.try_decrypt(pkesk, sym_algo, keypair, decrypt)
                 })
         };
 
         // First, we try those keys that we can use without prompting
         // for a password.
         for pkesk in pkesks {
-            let keyid = pkesk.recipient();
-            if let Some((cert, key)) = self.secret_keys.get(keyid) {
+            let keyid = pkesk.recipient().map(KeyID::from)
+                .unwrap_or_else(KeyID::wildcard);
+            if let Some((cert, key)) = self.secret_keys.get(&keyid) {
                 if let Some(fp) = decrypt_key(self, pkesk, cert, key, false) {
                     return Ok(fp);
                 }
@@ -235,8 +286,10 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                 continue;
             }
 
-            let keyid = pkesk.recipient();
-            if let Some((cert, key)) = self.secret_keys.get(keyid) {
+            let keyid = pkesk.recipient().map(KeyID::from);
+            if let Some((cert, key)) = keyid.as_ref()
+                .and_then(|k| self.secret_keys.get(k))
+            {
                 if let Some(fp) = decrypt_key(self, pkesk, cert, key, true) {
                     return Ok(fp);
                 }
@@ -246,7 +299,7 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
         // Third, we try to decrypt PKESK packets with wildcard
         // recipients using those keys that we can use without
         // prompting for a password.
-        for pkesk in pkesks.iter().filter(|p| p.recipient().is_wildcard()) {
+        for pkesk in pkesks.iter().filter(|p| p.recipient().is_none()) {
             for (cert, key) in self.secret_keys.values() {
                 if let Some(fp) = decrypt_key(self, pkesk, cert, key, false) {
                     return Ok(fp);
@@ -256,7 +309,7 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
 
         // Fourth, we try to decrypt PKESK packets with wildcard
         // recipients using those keys that are encrypted.
-        for pkesk in pkesks.iter().filter(|p| p.recipient().is_wildcard()) {
+        for pkesk in pkesks.iter().filter(|p| p.recipient().is_none()) {
             // Don't ask the user to decrypt a key if we don't support
             // the algorithm.
             if ! pkesk.pk_algo().is_supported() {
@@ -279,7 +332,7 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                     Ok((_i, fpr, sym_algo, sk)) => {
                         if let Some(fp) =
                             self.try_session_key(
-                                &KeyID::from(fpr), sym_algo, sk, &mut decrypt)
+                                &fpr, sym_algo, sk, decrypt)
                         {
                             return Ok(fp);
                         }
@@ -292,27 +345,55 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                                     let pkesk = key_status.pkesk().clone();
                                     let mut key = key_status.into_key();
                                     let keyid = key.keyid();
-                                    let userid = self.sq.best_userid_for(
-                                        &KeyHandle::from(&keyid), true);
+                                    let (userid, _) = self.sq.best_userid_for(
+                                        &KeyHandle::from(&keyid),
+                                        KeyFlags::empty()
+                                            .set_storage_encryption()
+                                            .set_transport_encryption(),
+                                        true);
 
-                                    let keypair = loop {
-                                        let password = rpassword::prompt_password(
-                                            format!(
-                                                "Enter password to unlock {}, {}: ",
-                                                keyid, userid))?
-                                            .into();
-
-                                        if let Ok(()) = key.unlock(password) {
-                                            break Box::new(key);
-                                        } else {
-                                            wprintln!("Bad password.");
+                                    loop {
+                                        if self.sq.batch {
+                                            eprintln!(
+                                                "{}, {} is locked, but not \
+                                                 prompting for password, \
+                                                 because you passed --batch.",
+                                                keyid, userid.display());
+                                            break;
                                         }
-                                    };
 
-                                    if let Some(fp) = self.try_decrypt(
-                                        &pkesk, sym_algo, keypair, &mut decrypt)
-                                    {
-                                        return Ok(fp);
+                                        match password::prompt_to_unlock_or_cancel(
+                                            self.sq,
+                                            &format!("{}, {}", keyid,
+                                                     userid.display()))
+                                        {
+                                            Err(err) => {
+                                                return Err(err).context(
+                                                    "Prompting for password");
+                                            }
+                                            Ok(Some(password)) => {
+                                                if let Err(_err) = key.unlock(password) {
+                                                    weprintln!("Bad password.");
+                                                    continue;
+                                                }
+                                            }
+                                            Ok(None) => {
+                                                // Cancelled.
+                                                weprintln!("Skipping {}, {}",
+                                                           keyid,
+                                                           userid.display());
+                                                break;
+                                            }
+                                        }
+
+                                        let keypair = Box::new(key);
+                                        if let Some(fp) = self.try_decrypt(
+                                            &pkesk, sym_algo, keypair, decrypt)
+                                        {
+                                            return Ok(fp);
+                                        } else {
+                                            break;
+                                        }
                                     }
                                 }
                             }
@@ -324,61 +405,53 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                 }
             }
             Err(err) => {
-                wprintln!("Warning: unable to connect to keystore: {}",
-                          err);
+                weprintln!("Warning: unable to connect to keystore: {}",
+                           err);
             }
         }
 
         if skesks.is_empty() {
-            let recipients = pkesks.iter()
-                .filter_map(|p| {
-                    let recipient = p.recipient();
-                    if recipient.is_wildcard() {
-                        None
-                    } else {
-                        Some(recipient)
-                    }
-                });
-            wprintln!("No key to decrypt message.  The message appears \
-                       to be encrypted to:");
-            wprintln!();
-            for recipient in recipients.into_iter() {
-                let certs = self.sq.lookup(
-                    std::iter::once(KeyHandle::from(recipient)),
-                    Some(KeyFlags::empty()
-                         .set_storage_encryption()
-                         .set_transport_encryption()),
-                    false,
-                    true);
+            weprintln!("No key to decrypt message.  The message appears \
+                        to be encrypted to:");
+            weprintln!();
 
-                match certs {
-                    Ok(certs) => {
-                        for cert in certs {
-                            wprintln!(initial_indent = "  - ",
-                                      "{}, {}",
-                                      cert.fingerprint(),
-                                      self.sq.best_userid(&cert, true));
+            for recipient in pkesks.iter().map(|p| p.recipient()) {
+                if let Some(r) = recipient {
+                    let certs = self.sq.lookup(
+                        std::iter::once(&r),
+                        Some(KeyFlags::empty()
+                             .set_storage_encryption()
+                             .set_transport_encryption()),
+                        false,
+                        true);
+
+                    match certs {
+                        Ok(certs) => {
+                            for cert in certs {
+                                ui::emit_cert(&mut io::stderr(), self.sq, &cert)?;
+                            }
+                        }
+                        Err(err) => {
+                            if let Some(StoreError::NotFound(_))
+                                = err.downcast_ref()
+                            {
+                                weprintln!(initial_indent = " - ",
+                                           "{}, certificate not found", r);
+                            } else {
+                                weprintln!(initial_indent = " - ",
+                                           "{}, error looking up certificate: {}",
+                                           r, err);
+                            }
                         }
                     }
-                    Err(err) => {
-                        if let Some(StoreError::NotFound(_))
-                            = err.downcast_ref()
-                        {
-                            wprintln!(initial_indent = "  - ",
-                                      "{}, certificate not found",
-                                      recipient);
-                        } else {
-                            wprintln!(initial_indent = "  - ",
-                                      "{}, error looking up certificate: {}",
-                                      recipient, err);
-                        }
-                    }
-                };
+                } else {
+                    weprintln!(initial_indent = " - ",
+                               "anonymous recipient, certificate not found");
+                }
             }
-            wprintln!();
 
-            return
-                Err(anyhow::anyhow!("No key to decrypt message"));
+            weprintln!();
+            return Err(anyhow::anyhow!("No key to decrypt message"));
         }
 
         // Finally, try to decrypt using the SKESKs.  Before
@@ -389,7 +462,7 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                     .and_then(|(algo, sk)| { if decrypt(algo, &sk) { Some(sk) } else { None }})
                 {
                     if self.dump_session_key {
-                        wprintln!("Session key: {}", hex::encode(&sk));
+                        weprintln!("Session key: {}", hex::encode(&sk));
                     }
                     return Ok(None);
                 }
@@ -407,7 +480,7 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
                     .and_then(|(algo, sk)| { if decrypt(algo, &sk) { Some(sk) } else { None }})
                 {
                     if self.dump_session_key {
-                        wprintln!("Session key: {}", hex::encode(&sk));
+                        weprintln!("Session key: {}", hex::encode(&sk));
                     }
                     return Ok(None);
                 }
@@ -418,11 +491,11 @@ impl<'c, 'store, 'rstore> DecryptionHelper for Helper<'c, 'store, 'rstore>
             }
 
             if first {
-                wprintln!("Incorrect password.  \
-                           Hint: enter empty password to cancel.");
+                weprintln!("Incorrect password.  \
+                            Hint: enter empty password to cancel.");
                 first = false;
             } else {
-                wprintln!("Incorrect password.");
+                weprintln!("Incorrect password.");
             }
         }
     }
@@ -446,6 +519,7 @@ pub fn decrypt(sq: Sq,
     io::copy(&mut decryptor, output).context("Decryption failed")?;
 
     let helper = decryptor.into_helper();
+    helper.print_status();
     helper.vhelper.print_status();
     Ok(())
 }
@@ -467,20 +541,19 @@ pub fn decrypt_unwrap(sq: Sq,
     let mut pkesks: Vec<packet::PKESK> = Vec::new();
     let mut skesks: Vec<packet::SKESK> = Vec::new();
     while let PacketParserResult::Some(mut pp) = ppr {
-        let sym_algo_hint = if let Packet::AED(ref aed) = pp.packet {
-            Some(aed.symmetric_algo())
-        } else {
-            None
+        let sym_algo_hint = match &pp.packet {
+            Packet::SEIP(SEIP::V2(seip)) => Some(seip.symmetric_algo()),
+            _ => None,
         };
 
         match pp.packet {
-            Packet::SEIP(_) | Packet::AED(_) => {
+            Packet::SEIP(_) => {
                 {
-                    let decrypt = |algo, secret: &SessionKey| {
+                    let mut decrypt = |algo, secret: &SessionKey| {
                         pp.decrypt(algo, secret).is_ok()
                     };
                     helper.decrypt(&pkesks[..], &skesks[..], sym_algo_hint,
-                                   decrypt)?;
+                                   &mut decrypt)?;
                 }
                 if ! pp.processed() {
                     return Err(
