@@ -1,19 +1,16 @@
 use sequoia_openpgp as openpgp;
 use openpgp::cert::CertRevocationBuilder;
 use openpgp::packet::signature::subpacket::NotationData;
-use openpgp::parse::Parse;
 use openpgp::types::ReasonForRevocation;
 use openpgp::Cert;
 use openpgp::Packet;
 use openpgp::Result;
 
 use crate::Sq;
-use crate::cli::key::RevokeCommand;
-use crate::cli::types::FileOrStdout;
+use crate::cli::key::revoke::Command;
 use crate::common::get_secret_signer;
-use crate::common::NULL_POLICY;
 use crate::common::RevocationOutput;
-use crate::parse_notations;
+use crate::sq::TrustThreshold;
 
 /// Handle the revocation of a certificate
 struct CertificateRevocation {
@@ -75,8 +72,8 @@ impl RevocationOutput for CertificateRevocation
     }
 
     fn comment(&self) -> String {
-        "Includes a revocation certificate for the certificate"
-            .to_string()
+        format!("This is a revocation certificate for the cert {}.",
+                self.cert.fingerprint())
     }
 
     fn revoker(&self) -> &Cert {
@@ -87,35 +84,18 @@ impl RevocationOutput for CertificateRevocation
 /// Revoke a certificate
 pub fn certificate_revoke(
     sq: Sq,
-    mut command: RevokeCommand,
+    command: Command,
 ) -> Result<()> {
-    let cert = if let Some(file) = command.cert_file {
-        if command.output.is_none() {
-            // None means to write to the cert store.  When reading
-            // from a file, we want to write to stdout by default.
-            command.output = Some(FileOrStdout::new(None));
-        }
+    let cert =
+        sq.resolve_cert(&command.cert, TrustThreshold::Full)?.0;
 
-        let br = file.open()?;
-        Cert::from_buffered_reader(br)?
-    } else if let Some(kh) = command.cert {
-        sq.lookup_one_with_policy(&kh, None, true,
-                                  NULL_POLICY, sq.time)?
-    } else {
-        panic!("clap enforces --cert or --cert-file");
-    };
-
-    let revoker = if let Some(file) = command.revoker_file {
-        let br = file.open()?;
-        Some(Cert::from_buffered_reader(br)?)
-    } else if let Some(kh) = command.revoker {
-        Some(sq.lookup_one_with_policy(&kh, None, true,
-                                       NULL_POLICY, sq.time)?)
-    } else {
+    let revoker = if command.revoker.is_empty() {
         None
+    } else {
+        Some(sq.resolve_cert(&command.revoker, TrustThreshold::Full)?.0)
     };
 
-    let notations = parse_notations(command.notation)?;
+    let notations = command.signature_notations.parse()?;
 
     let revocation = CertificateRevocation::new(
         &sq,
@@ -125,7 +105,7 @@ pub fn certificate_revoke(
         &command.message,
         &notations,
     )?;
-    revocation.write(&sq, command.output, command.binary)?;
+    revocation.write(&sq, command.output, false)?;
 
     Ok(())
 }
