@@ -66,7 +66,7 @@ use crate::print_error_chain;
 
 const TRACE: bool = false;
 
-pub static NULL_POLICY: NullPolicy = NullPolicy::new();
+pub static NULL_POLICY: NullPolicy = unsafe { NullPolicy::new() };
 
 /// Flags for Sq::get_keys and related functions.
 #[derive(Debug, Clone, PartialEq, Eq)]
@@ -607,10 +607,10 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                     };
 
                     let checked_id = or_by_primary
-                        && vc.key_handle().aliases(&kh);
+                        && vc.cert().key_handle().aliases(&kh);
 
                     for ka in vc.keys() {
-                        if checked_id || ka.key_handle().aliases(&kh) {
+                        if checked_id || ka.key().key_handle().aliases(&kh) {
                             if &ka.key_flags().unwrap_or(KeyFlags::empty())
                                 & keyflags
                                 != KeyFlags::empty()
@@ -626,7 +626,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                                    cert.keyid(), keyflags);
                     } else {
                         weprintln!("Error: The subkey {} (cert: {}) \
-                                    does not the required capabilities \
+                                    does not have the required capabilities \
                                     ({:?})",
                                    kh, cert.keyid(), keyflags);
                     }
@@ -1029,6 +1029,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
         // Also insert the certificate into the certificate store.
         // If we can't, we don't fail.  This allows, in
         // particular, `sq --cert-store=none key import` to work.
+        let cert = cert.strip_secret_key_material();
         let fpr = cert.fingerprint();
         let mut cert_import_status = ImportStatus::Unchanged;
         match self.cert_store_or_else() {
@@ -1270,7 +1271,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                 }
 
                 for p in self.password_cache.lock().unwrap().iter() {
-                    if let Ok(unencrypted) = e.decrypt(key.pk_algo(), &p) {
+                    if let Ok(unencrypted) = e.decrypt(&key, &p) {
                         let (key, _) = key.add_secret(unencrypted.into());
                         return Ok(key);
                     }
@@ -1279,7 +1280,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                 let prompt = if let Some(cert) = cert {
                     format!("{}/{} {}",
                             cert.keyid(), key.keyid(),
-                            self.best_userid(cert, true))
+                            self.best_userid(cert, true).display())
                 } else {
                     format!("{}", key.keyid())
                 };
@@ -1299,7 +1300,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                     match result {
                         Ok(None) => break, // Give up.
                         Ok(Some(p)) => {
-                            if let Ok(unencrypted) = e.decrypt(key.pk_algo(), &p) {
+                            if let Ok(unencrypted) = e.decrypt(&key, &p) {
                                 let (key, _) = key.add_secret(unencrypted.into());
                                 self.password_cache.lock().unwrap().push(p);
                                 return Ok(key);
@@ -1352,7 +1353,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
         {
             let ks = self.key_store_or_else()?;
             let mut ks = ks.lock().unwrap();
-            if ks.find_key(ka.key_handle())?.is_empty() {
+            if ks.find_key(ka.key().key_handle())?.is_empty() {
                 Err(anyhow!("no secret key material in the store"))
             } else {
                 Ok(())
@@ -1414,7 +1415,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
 
             let mut ks = ks.lock().unwrap();
 
-            let remote_keys = ks.find_key(ka.key_handle())?;
+            let remote_keys = ks.find_key(ka.key().key_handle())?;
 
             let uid = self.best_userid(ka.cert(), true);
 
@@ -1437,7 +1438,8 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                         loop {
                             let p = password::prompt_to_unlock(self, &format!(
                                 "{}/{}, {}",
-                                ka.cert().keyid(), ka.keyid(), uid))?;
+                                ka.cert().keyid(), ka.key().keyid(),
+                                uid.display()))?;
 
                             if p == "".into() {
                                 weprintln!("Giving up.");
@@ -1542,20 +1544,20 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                     ! allow_not_alive && matches!(ka.alive(), Err(_)),
                     ! allow_revoked && matches!(ka.revocation_status(),
                                                 RevocationStatus::Revoked(_)),
-                    ! ka.pk_algo().is_supported(),
+                    ! ka.key().pk_algo().is_supported(),
                     false,
                 ];
                 if bad_.iter().any(|x| *x) {
-                    bad.push((ka.fingerprint(), bad_));
+                    bad.push((ka.key().fingerprint(), bad_));
                     continue;
                 }
 
-                if let Ok(key) = self.get_signer(&ka) {
+                if let Ok(key) = self.get_signer(ka.amalgamation()) {
                     keys.push((cert.clone(), key));
                     continue 'next_cert;
                 } else {
                     bad_[3] = true;
-                    bad.push((ka.fingerprint(), bad_));
+                    bad.push((ka.key().fingerprint(), bad_));
                     continue;
                 }
             }
@@ -2184,20 +2186,20 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                     let (certs, config): (Box<dyn Iterator<Item=&Fingerprint>>, _)
                         = match prefix
                     {
-                        "for" => (
+                        "for-" => (
                             Box::new(self.config.encrypt_for_self().iter()),
                             cli::encrypt::ENCRYPT_FOR_SELF,
                         ),
-                        "signer" => (
+                        "signer-" => (
                             Box::new(self.config.sign_signer_self().iter()),
                             cli::sign::SIGNER_SELF,
                         ),
-                        "certifier" => (
+                        "certifier-" => (
                             Box::new(self.config.pki_vouch_certifier_self().iter()),
                             cli::pki::vouch::CERTIFIER_SELF,
                         ),
                         _ => return Err(anyhow::anyhow!(
-                            "self designator used with unexpected prefix")),
+                            "self designator used with unexpected prefix: {}", prefix)),
                     };
 
                     let mut one = false;
@@ -2213,7 +2215,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
 
                     if ! one {
                         return Err(anyhow::anyhow!(
-                            "`--{}-self` is given but no default \
+                            "`--{}self` is given but no default \
                              is set in the configuration file under `{}`",
                             prefix,
                             config));
@@ -2410,7 +2412,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
             for cert in certs.iter() {
                 eprintln!("  - {} {}",
                           cert.fingerprint(),
-                          self.best_userid(cert, true));
+                          self.best_userid(cert, true).display());
             }
 
             return Err(anyhow::anyhow!(
@@ -2474,7 +2476,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                 if only_subkeys && ka.primary() {
                     let err = format!(
                         "Selected key {} is a primary key, not a subkey.",
-                        ka.fingerprint());
+                        ka.key().fingerprint());
                     weprintln!("{}", err);
                     bad.push(anyhow::anyhow!(err));
                     continue;
@@ -2504,7 +2506,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                 if hard_revoked {
                     let err = anyhow::anyhow!(
                         "Can't use {}, it is hard revoked",
-                        ka.fingerprint());
+                        ka.key().fingerprint());
                     weprintln!("{}", err);
                     bad.push(err);
                 } else {
@@ -2518,7 +2520,7 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
                 // in some way.  This isn't enough to return it, but
                 // we may be able to generate a better error message.
 
-                let fingerprint = ka.fingerprint();
+                let fingerprint = ka.key().fingerprint();
 
                 let err = match ka.with_policy(vc.policy(), vc.time()) {
                     Ok(_) => unreachable!("key magically became usable"),
@@ -2569,13 +2571,13 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
         if ! missing.is_empty() {
             weprintln!();
             if only_subkeys {
-                weprintln!("{} has the following subkeys:", vc.fingerprint());
+                weprintln!("{} has the following subkeys:", vc.cert().fingerprint());
             } else {
-                weprintln!("{} has the following keys:", vc.fingerprint());
+                weprintln!("{} has the following keys:", vc.cert().fingerprint());
             }
             weprintln!();
             for ka in vc.keys().skip(if only_subkeys { 1 } else { 0 }) {
-                weprintln!(" - {}", ka.fingerprint());
+                weprintln!(" - {}", ka.key().fingerprint());
             }
         }
 
@@ -2587,8 +2589,8 @@ impl<'store: 'rstore, 'rstore> Sq<'store, 'rstore> {
         }
 
         // Dedup.
-        kas.sort_by_key(|ka| ka.fingerprint());
-        kas.dedup_by_key(|ka| ka.fingerprint());
+        kas.sort_by_key(|ka| ka.key().fingerprint());
+        kas.dedup_by_key(|ka| ka.key().fingerprint());
 
         assert!(kas.len() > 0);
 
